from setuptools import setup, find_packages


 
setup(
    
  name='OwlSense',
  version='0.7',
  description='Python lib for basic&advance AI,ML',
  author='sebinmon.vr',
  author_email='nthn8777@gmail.com',
  license='MIT', 
  packages=find_packages(),
  install_requires=['openai==0.28'] ,
  entry_points = {
    'console_scripts': ['OwlSense=OwlSense.main:Owl'],
  },
  
)




import openai

def OwlSense():
    print("Owl")
    
def ottaha():
    camel_ascii = r"""
     ___.-''''-.
    /___  @    |
    ',,,,.     |         _.'''''''._
         '     |        /           \
         |     \    _.-'             \
         |      '.-'                  '-.
         |                               ',
         |                                '',
          ',,-,                           ':;
               ',,| ;,,                 ,' ;;
                  ! ; !'',,,',',,,,'!  ;   ;:
                 : ;  ! !       ! ! ;  ;   :;
                 ; ;   ! !      ! !  ; ;   ;,
                ; ;    ! !     ! !   ; ;     
                ; ;    ! !    ! !     ; ;
               ;,,      !,!   !,!     ;,;
               /_I      L_I   L_I     /_I
"""
    print(camel_ascii)
    print("Ottaha")

    
    
    
    
# def gpt(OPENAI_API_KEY , models , promopt):

#     openai.api_key = OPENAI_API_KEY
#     response = openai.ChatCompletion.create(
#         model=models,
#         messages=[{"role": "user", "content": f"{promopt}"}]
#     )
#     return(response.choices[0].message.content)
    